@@ -1,28 +1,23 @@
-//============================================================================
-//
-// Terence Welsh Screensaver - Flux
-// http://www.reallyslick.com/
-//
-// Ported to KDE by Karl Robillard
-//
 /*
- * Copyright (C) 2002  Terence M. Welsh
+ *  Terence Welsh Screensaver - Flux
+ *  http://www.reallyslick.com/
  *
- * Flux is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation.
+ *  Ported to KDE by Karl Robillard
+ *  Copyright (C) 2002  Terence M. Welsh
  *
- * Flux is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *   
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *   
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-//============================================================================
-
 
 /*
   TODO
@@ -37,6 +32,7 @@
 #include <math.h>
 #include <time.h>
 #include <qtimer.h>
+
 #include "Flux.h"
 #include "Flux.moc"
 
@@ -429,8 +425,8 @@ void flux::update()
 //----------------------------------------------------------------------------
 
 
-FluxWidget::FluxWidget( QWidget* parent, const char* name )
-                      : QGLWidget(parent, name), _fluxes(0)
+FluxWidget::FluxWidget( QWidget* parent )
+                      : QGLWidget(parent), _fluxes(0)
 {
     setDefaults( Regular );
 
@@ -538,8 +534,8 @@ void FluxWidget::initializeGL()
     //resizeGL( width(), height() );
 
     updateParameters();
-
-    _timer->start( _frameTime, true );
+    _timer->setSingleShot(true);
+    _timer->start( _frameTime );
 }
 
 
@@ -559,7 +555,8 @@ void FluxWidget::keyPressEvent( QKeyEvent* e )
 void FluxWidget::nextFrame()
 {
     updateGL();
-    _timer->start( _frameTime, true );
+    _timer->setSingleShot(true);
+    _timer->start( _frameTime );
 }
 
 
@@ -778,21 +775,31 @@ void FluxWidget::updateParameters()
 
 
 // libkscreensaver interface
-extern "C"
+class KFluxSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char* kss_applicationName = "kflux.kss";
-    KDE_EXPORT const char* kss_description = I18N_NOOP( "Flux" );
-    KDE_EXPORT const char* kss_version = "1.0";
 
-    KDE_EXPORT KScreenSaver* kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kflux.kss", 0, ki18n( "Flux" ), "1.0", ki18n( "Flux" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new KFluxScreenSaver( id );
     }
 
-    KDE_EXPORT QDialog* kss_setup()
+    virtual QDialog* setup()
     {
         return new KFluxSetup;
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KFluxSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 
@@ -828,10 +835,9 @@ static int filterRandom( int n )
 
 void KFluxScreenSaver::readSettings()
 {
-    KConfig* config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    _mode = config->readNumEntry( "Mode", FluxWidget::Regular );
+    _mode = config.readEntry( "Mode", (int)FluxWidget::Regular );
     _flux->setDefaults( filterRandom(_mode) );
 }
 
@@ -854,7 +860,6 @@ void KFluxScreenSaver::setMode( int id )
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qcombobox.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
 
 
@@ -871,14 +876,19 @@ static const char* defaultText[] =
 };
 
 
-KFluxSetup::KFluxSetup( QWidget* parent, const char* name )
-    : KDialogBase( parent, name, true, i18n( "Setup Flux Screen Saver" ),
-      Ok|Cancel|Help, Ok, true )
+KFluxSetup::KFluxSetup( QWidget* parent )
+    : KDialog( parent)
 {
     setButtonText( Help, i18n( "A&bout" ) );
-    QWidget *main = makeMainWidget();
+	setButtons(Ok|Cancel|Help);
+	setDefaultButton(Ok);
+	setModal(true);
+	showButtonSeparator(true);
+    QWidget *main = new QWidget(this);
+	setMainWidget(main);
 
-    QHBoxLayout* top = new QHBoxLayout( main, 0, spacingHint() );
+    QHBoxLayout* top = new QHBoxLayout( main );
+    top->setSpacing( spacingHint() );
     QVBoxLayout* leftCol = new QVBoxLayout;
     top->addLayout( leftCol );
 
@@ -889,7 +899,7 @@ KFluxSetup::KFluxSetup( QWidget* parent, const char* name )
     modeW = new QComboBox( main );
     int i = 0;
     while (defaultText[i])
-        modeW->insertItem( i18n(defaultText[i++]) );
+        modeW->addItem( i18n(defaultText[i++]) );
     leftCol->addWidget( modeW );
 
     leftCol->addStretch();
@@ -898,14 +908,20 @@ KFluxSetup::KFluxSetup( QWidget* parent, const char* name )
     QWidget* preview;
     preview = new QWidget( main );
     preview->setFixedSize( 220, 165 );
-    preview->setBackgroundColor( black );
+    {
+        QPalette palette;
+        palette.setColor( preview->backgroundRole(), Qt::black );
+        preview->setPalette( palette );
+    }
     preview->show();    // otherwise saver does not get correct size
     _saver = new KFluxScreenSaver( preview->winId() );
     top->addWidget(preview);
 
     // Now that we have _saver...
-    modeW->setCurrentItem( _saver->mode() );    // set before we connect
-    connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
+    modeW->setCurrentIndex( _saver->mode() );    // set before we connect
+   connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
+   connect( this, SIGNAL(okClicked()), SLOT(slotOk()));
+   connect(this, SIGNAL(helpClicked()),SLOT(slotHelp()));
 }
 
 
@@ -919,7 +935,7 @@ void KFluxSetup::slotHelp()
 {
     KMessageBox::about(this,
         i18n("<h3>Flux 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
-        QString::null, KMessageBox::AllowLink);
+        QString(), KMessageBox::AllowLink);
 }
 
 
@@ -928,14 +944,13 @@ void KFluxSetup::slotHelp()
 */
 void KFluxSetup::slotOk()
 {
-    KConfig* config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
     QString val;
-    val.setNum( modeW->currentItem() );
-    config->writeEntry("Mode", val );
+    val.setNum( modeW->currentIndex() );
+    config.writeEntry("Mode", val );
 
-    config->sync();
+    config.sync();
     accept();
 }
 #endif
