@@ -11,8 +11,8 @@
 // the same.
 ////
 
-#ifndef __GRAVITY_H__
-#define __GRAVITY_H__
+#ifndef GRAVITY_H
+#define GRAVITY_H
 
 #include <qdialog.h>
 #include <qgl.h>
@@ -26,8 +26,8 @@
 #include <kscreensaver.h>
 #include <qtimer.h>
 #include <qimage.h>
-#include "gravitycfg.h"
-#include <kinstance.h>
+#include "ui_gravitycfg.h"
+#include <kcomponentdata.h>
 #include <qfile.h>
 #include <qtextstream.h>
 
@@ -58,7 +58,7 @@ Q_OBJECT
 	};
 
 public:
-	Gravity( QWidget * parent=0, const char * name=0 );
+	Gravity( QWidget * parent=0 );
 	~Gravity();
 	void setSize( float newSize );
 	void setStars( bool doStars );
@@ -67,7 +67,7 @@ protected:
 	void paintGL ();
 	/** resize the gl view */
 	void resizeGL ( int w, int h );
-	/** setup the GL enviroment */
+	/** setup the GL environment */
 	void initializeGL ();
 	void buildParticle(int loop);
 
@@ -115,12 +115,12 @@ private:
 	QTimer  *timer;
 };
 
-class KGravitySetup : public SetupUi
+class KGravitySetup : public QDialog, public Ui::SetupUi
 {
 	Q_OBJECT
 public:
-	KGravitySetup( QWidget *parent = NULL, const char *name = NULL );
-    ~KGravitySetup();
+	KGravitySetup( QWidget *parent = 0L);
+        ~KGravitySetup();
 
 protected:
 	void readSettings();
